/*
 *   khexedit - Versatile hex editor
 *   Copyright (C) 1999  Espen Sand, espensa@online.no
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

#include "hexmanagerwidget.h"

CHexManagerWidget::CHexManagerWidget( QWidget *parent, const char *name,
				      EConversionPosition position )
  : QWidget( parent, name )
{
  mValid = false;

  mEditor = new CHexEditorWidget( this );
  if( mEditor == 0 ) { return; }
  
  mUtil = new CHexToolWidget( this );
  if( mUtil == 0 ) { return; }

  connect( mEditor->view(), SIGNAL( cursorChanged( SCursorState & ) ),
	   mUtil, SLOT( cursorChanged( SCursorState & ) ) );
  connect( mUtil, SIGNAL( closed(void) ), SIGNAL( conversionClosed( void ) ) );

  mY = 0;//15;
  mValid = true;
  setConversionVisibility( position );
}


CHexManagerWidget::~CHexManagerWidget( void )
{
  delete mEditor;
  delete mUtil;
}


void CHexManagerWidget::resizeEvent( QResizeEvent *e )
{
  if( mConversionPosition != InEditor )
  {
    mEditor->setGeometry( 0, mY, width(), height()-mY );
  }
  else
  {
    uint utilHeight = mUtil->minimumSize().height();
    mEditor->setGeometry( 0, mY, width(), height() - utilHeight - mY );
    mUtil->setGeometry( 0, height() - utilHeight, width(), utilHeight );
  }
}


void CHexManagerWidget::setConversionVisibility( EConversionPosition position )
{
  if( mValid == false )
  {
    return;
  }

  if( mConversionPosition == position )
  {
    if( mConversionPosition == InWindow )
    {
      mUtil->raise();
    }
    return;
  }

  mConversionPosition = position;
  if( mConversionPosition == Hide )
  {
    mEditor->setGeometry( 0, mY, width(), height()-mY );
    mUtil->hide();
  }
  else if( mConversionPosition == InWindow )
  {
    mEditor->setGeometry( 0, mY, width(), height()-mY );
    QPoint point = mapToGlobal( QPoint(0,0) );
    QRect  rect  = geometry();
    QPoint p;
    
    p.setX( point.x() + rect.width()/2 - mUtil->minimumSize().width()/2 );
    p.setY( point.y() + rect.height()/2 - mUtil->minimumSize().height()/2 );
    mUtil->resize( mUtil->minimumSize() );
    mUtil->recreate( 0, WStyle_Customize | WStyle_DialogBorder, p, true );
    mUtil->setCaption( i18n("Conversion") );
  }
  else
  {
    mConversionPosition = InEditor;
    uint utilHeight = mUtil->minimumSize().height();
    mEditor->setGeometry( 0, mY, width(), height() - utilHeight - mY);
    QPoint p( 0, height() - utilHeight );
    mUtil->recreate( this, 0, p, true );
    mUtil->setGeometry( 0, height() - utilHeight, width(), utilHeight );
  }

}







