/*
 *   khexedit - Versatile hex editor
 *   Copyright (C) 1999  Espen Sand, espensa@online.no
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

#include <kapp.h>
#include "toplevel.h"

#include <getopt.h>
#include <iostream.h>
#include <unistd.h>

static uint parseDecimalOrHexadecimal( char *buf );


int main( int argc, char **argv )
{
  QString appName( "khexedit" );
  KApplication app( argc, argv, appName );
  
  if( app.isRestored() != 0 )
  {
    RESTORE( KHexEdit );
  }
  else
  {
    KHexEdit *hexEdit = new KHexEdit;
    if( hexEdit == 0 || hexEdit->isValid() == false )
    {
      cerr << "Unable to start - Memory exhausted" << endl;
      return( 1 );
    }

    hexEdit->show();

    if( argc > 1 )
    {
      static struct option options[] =
      {
	{"offset", 1, 0, 1},
	{0, 0, 0, 0}
      };

      while( 1 )
      {
	int index;
	int optVal = getopt_long_only( argc, argv, "", options, &index );
	if( optVal == -1 ) 
	{ 
	  break; 
	}
	else if( optVal == 1 )
	{
	  hexEdit->setStartupOffset( parseDecimalOrHexadecimal(optarg) );
	  break;
	}
      }

      while( optind < argc )
      {
	hexEdit->addStartupFile( argv[optind++] );
      }
    }

    #if 0
    //
    // For now we assume all commandline args. that have not been 
    // detected are filenames.
    //
    if( argc > 1 )
    {
      for( int i=1; i<argc; i++)
      {
	hexEdit->addStartupFile( argv[i] );
      }
    }
    #endif

  }

  return( app.exec() );
}





static uint parseDecimalOrHexadecimal( char *buf )
{
  if( buf == 0 ) { return( 0 ); }
  
  long int value;
  char *end = 0;
	    
  value = strtol( optarg, &end, 10 );
  if( *end != 0 )
  {
    value = strtol( optarg, &end, 16 );
    if( *end != 0 )
    {
      value = 0;
    }
  }
  if( value < 0 ) { value = 0; }
  return( value );
}

