/*
 *   khexedit - Versatile hex editor
 *   Copyright (C) 1999  Espen Sand, espensa@online.no
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

#ifndef _STRING_DIALOG_H_
#define _STRING_DIALOG_H_

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif 

#include <qcheckbox.h>
#include <qdialog.h> 
#include <qlabel.h>
#include <qlineedit.h>
#include <qlist.h> 
#include <qlistbox.h>
#include <qregexp.h> 
#include <qspinbox.h> 

#include "hexbuffer.h"
#include "progress.h"


class CStringDialog : public QDialog 
{
  Q_OBJECT
  
  public:
    CStringDialog( QWidget *parent, const char *name = 0 );
    ~CStringDialog( void );

    int  setList( QList<QString> &list, CProgress &p );
    inline CStringCollectControl &stringData( void );

  signals:
    void markText( uint offset, uint size, bool moveCursor );
    void collect( void );

  public slots:
    void clearList( void );  // Removes list entries
    void removeList( void ); // Removes list entries and the string list.

  protected slots:
    virtual void help( void );
    virtual void startCapture( void );
    virtual void startGoto( int index );
    virtual void selectionChanged( int index );

  protected:
    virtual void timerEvent( QTimerEvent *e );

  private:
    void enableList( bool state );
    void appendListItem( const QString &str );
    void updateListInfo( void );

  private:
    CStringCollectControl mStringData;
    QRegExp mRegExp;
    bool mBusy;

    QSpinBox  *mLengthSpin;
    QLineEdit *mFilter;
    QCheckBox *mCheckIngoreCase;
    QListBox  *mStringList;
    QLabel    *mListSizeLabel;
    QLabel    *mDisplaySizeLabel;
};


CStringCollectControl &CStringDialog::stringData( void )
{
  return( mStringData );
}

#endif
